# Worky
Manage your workspaces and increase your productivity.

## What is Worky?
Worky is a tool that helps to define and load project workspaces. It can be used to load a project workspace with a single command and quickly start your work.
Worky saves you from wasting time doing repetitive tasks before actually starting to work.

## Future improvements
Please note that this is a work in progress tool. If you have any idea or suggestion, please open an issue or a pull request.
Any helps is appreciated. Here is a list of future improvements:
- [ ] Add the project to PyPI

## For developers
Install dependencies:
```shell
pyenv local 3.11.1
poetry use env 3.11.1
poetry install
poetry run start {{your_command_args}}
```

## Getting started
### Installation
### Configuration
### Usage



